dnl @synopsis ACX_LAPACK([ACTION-IF-FOUND[, ACTION-IF-NOT-FOUND]])
dnl
dnl This macro looks for a library that implements the LAPACK
dnl linear-algebra interface (see http://www.netlib.org/lapack/).
dnl On success, it sets the LAPACK_LIBS output variable to
dnl hold the requisite library linkages.
dnl
dnl To link with LAPACK, you should link with:
dnl
dnl     $LAPACK_LIBS $BLAS_LIBS $LIBS
dnl
dnl in that order.  BLAS_LIBS is the output variable of the AC_FC_BLAS
dnl macro, called automatically.  
dnl
dnl The user may also use --with-lapack=<lib> in order to use some
dnl specific LAPACK library <lib>.  In order to link successfully,
dnl however, be aware that you will probably need to use the same
dnl Fortran compiler (which can be set via the F77 env. var.) as
dnl was used to compile the LAPACK and BLAS libraries.
dnl
dnl ACTION-IF-FOUND is a list of shell commands to run if a LAPACK
dnl library is found, and ACTION-IF-NOT-FOUND is a list of commands
dnl to run it if it is not found.  If ACTION-IF-FOUND is not specified,
dnl the default action will define HAVE_LAPACK.
dnl
dnl @version $Id: ac_fc_lapack.m4,v 1.1.1.1 2005/10/26 09:58:30 dumas Exp $
dnl @author Steven G. Johnson <stevenj@alum.mit.edu>

AC_DEFUN([AC_FC_LAPACK], [
AC_REQUIRE([AC_FC_BLAS])
ac_fc_lapack_ok=no

AC_ARG_WITH(lapack,
        [AC_HELP_STRING([--with-lapack=<lib>], [use LAPACK library <lib>])])
case $with_lapack in
        yes | "") ;;
        no) ac_fc_lapack_ok=disable ;;
        -* | */* | *.a | *.so | *.so.* | *.o) LAPACK_LIBS="$with_lapack" ;;
        *) LAPACK_LIBS="-l$with_lapack" ;;
esac

# We cannot use LAPACK if BLAS is not found
if test "x$ac_fc_blas_ok" != xyes; then
        ac_fc_lapack_ok=noblas
fi

# First, check LAPACK_LIBS environment variable
if test "x$LAPACK_LIBS" != x; then
        save_LIBS="$LIBS"; LIBS="$LAPACK_LIBS $BLAS_LIBS $LIBS"
        AC_MSG_CHECKING([for cheev in $LAPACK_LIBS])
        AC_TRY_LINK_FUNC(cheev, [ac_fc_lapack_ok=yes], [LAPACK_LIBS=""])
        AC_MSG_RESULT($ac_fc_lapack_ok)
        LIBS="$save_LIBS"
        if test ac_fc_lapack_ok = no; then
                LAPACK_LIBS=""
        fi
fi

# atlas
if test $ac_fc_lapack_ok = no; then
        save_LIBS="$LIBS"; LIBS="$LIBS $BLAS_LIBS"
        AC_CHECK_LIB(lapack, cheev,
           [ac_fc_lapack_ok=yes; LAPACK_LIBS="-llapack -lcblas"], [], [-lcblas])
        LIBS="$save_LIBS"
fi

# LAPACK linked to by default?  (is sometimes included in BLAS lib)
if test $ac_fc_lapack_ok = no; then
        save_LIBS="$LIBS"; LIBS="$LIBS $BLAS_LIBS"
        AC_MSG_CHECKING([for cheev linked by default])
        AC_TRY_LINK_FUNC(cheev, [ac_fc_lapack_ok=yes])
        AC_MSG_RESULT($ac_fc_lapack_ok)
        LIBS="$save_LIBS"
fi

# Generic LAPACK library?
for lapack in lapack lapack_rs6k f77lapack; do
        if test $ac_fc_lapack_ok = no; then
                save_LIBS="$LIBS"; LIBS="$BLAS_LIBS $LIBS"
                AC_CHECK_LIB($lapack, cheev,
                    [ac_fc_lapack_ok=yes; LAPACK_LIBS="-l$lapack"], [], [])
                LIBS="$save_LIBS"
        fi
done

AC_SUBST(LAPACK_LIBS)

# Finally, execute ACTION-IF-FOUND/ACTION-IF-NOT-FOUND:
if test x"$ac_fc_lapack_ok" = xyes; then
        ifelse([$1],,AC_DEFINE(HAVE_LAPACK,1,[Define if you have LAPACK library.]),[$1])
        :
else
        ac_fc_lapack_ok=no
        $2
fi
])dnl ACX_LAPACK
